@@ -1,5 +1,5 @@
 `RidgePlot` <-
-function(ridges,x,y,ptitle="Ridges",labels=NULL,col=NULL)
+function(ridges,x,y,ptitle="Ridges",labels=NULL,col=NULL,...)
 {
         slen = length(x)
 	if (missing(y)) 
@@ -9,11 +9,11 @@ function(ridges,x,y,ptitle="Ridges",labels=NULL,col=NULL)
 	}
 	if (missing(col)) 
 		col <- rep("#8888FF",length(ridges));
-        plot(x,y,t="n",main=ptitle)
+        plot(x,y,t="n",main=ptitle,...)
 	for (i in 1:length(ridges)) {	
 	        r <- ridges[[i]] 
 		if (!is.null(r$r.start)) {
-       	     		rect(r$r.start,min(y),r$r.end,max(y),col=col[i],border=NA)
+       	     		rect(r$r.start,min(y[y>-1e300]),r$r.end,max(y[y<1e300]),col=col[i],border=NA)
 		}
 	}
         lines(x,y)
